@@ -139,15 +139,15 @@ class Stock:
 		self.df = get_intra_day_data(self.ticker)
 		self.df_month = get_month_data(self.ticker)
 
-	def _find_match(pattern, text):
+	def _find_match(self, pattern, text):
 		match = pattern.search(text)
 		return match
 
-	def _no_attributes(tag):
+	def _no_attributes(self, tag):
 		if 'td' in str(tag):
 			return tag.has_attr('class') or tag.has_attr('id')
 
-	def _get_soup(url):
+	def _get_soup(self, url):
 		response = get(url, headers=HEADERS, timeout=20)
 		assert response.status_code == 200
 		return BeautifulSoup(response.content, 'lxml')
@@ -159,12 +159,12 @@ class Stock:
 	# Make this all one big function
 	def get_summary(self):
 		BASE_URL = f'https://www.marketwatch.com/investing/stock/{self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		summary = soup.find('p', {'class': 'description__text'})
 
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		website = soup.find('a', {'title': 'Company Profile'})
 		if website:
 			website = website['href']
@@ -177,7 +177,7 @@ class Stock:
 	def basic_stats(self):
 		# Market cap, avg volume, financial information
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}/key-statistics?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		info = []
 
@@ -194,7 +194,7 @@ class Stock:
 		# Income Statement
 		nerd_info = []
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}/financials?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		rows = soup.find_all('div', {'data-test': 'fin-row'})
 		for row in rows:
 			title = row.find('div', {'class': 'D(tbc) Ta(start) Pend(15px)--mv2 Pend(10px) Bxz(bb) Py(8px) Bdends(s) Bdbs(s) Bdstarts(s) Bdstartw(1px) Bdbw(1px) Bdendw(1px) Bdc($seperatorColor) Pos(st) Start(0) Bgc($lv2BgColor) fi-row:h_Bgc($hoverBgColor) Pstart(15px)--mv2 Pstart(10px)'})
@@ -203,7 +203,7 @@ class Stock:
 		
 		# Balance Sheet
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}/balance-sheet?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		rows = soup.find_all('div', {'data-test': 'fin-row'})
 		for row in rows:
 			title = row.find('D(ib) Fw(b) Ta(start) Px(15px)--mv2 Px(10px) W(247px)--mv2 W(222px) Bxz(bb) Bdendw(1px) Bdstartw(1px) Bdbw(1px) Bdends(s) Bdstarts(s) Bdbs(s) Bdc($seperatorColor) Py(6px) Pos(st) Start(0) Bgc($lv2BgColor)')
@@ -216,13 +216,13 @@ class Stock:
 
 	def price_target(self, exchange='NASDAQ'): # Automatically find correct stock exchange
 		BASE_URL = f'https://www.marketbeat.com/stocks/{exchange}/{self.ticker}/price-target/'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		
 		price_target = soup.find('table', {'class': 'scroll-table'})
 		_pattern = re.compile(r'Price Target: \$\d{1,3}\.\d\d')
-		price_target = _find_match(_pattern, table.get_text()).group(0)
+		price_target = self._find_match(_pattern, table.get_text()).group(0)
 		_pattern = re.compile(r'\d{1,3}\.\d\d\% \w{6,8}')
-		percentage = _find_match(_pattern, table.get_text()).group(0)
+		percentage = self._find_match(_pattern, table.get_text()).group(0)
 
 		BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
 		response = get(BASE_URL, headers=HEADERS, timeout=20)
@@ -242,7 +242,7 @@ class Stock:
 
 	def price_predictions(self):
 		BASE_URL = f'https://www.barchart.com/stocks/quotes/{self.ticker}/opinion'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		table = soup.find('table', {'data-ng-class': "{'hide': currentView !== 'strengthDirection'}"})
 		titles = soup.find_all('tr', {'class': 'indicator-title'})
@@ -261,7 +261,7 @@ class Stock:
 
 	def ta_indictators(self): # Loads wrong page. Beta, RSI history, above/below 9 SMA, above/below 180 SMA, volatility, rel volume
 		BASE_URL = f'https://www.tradingview.com/symbols/{self.ticker}/technicals/'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		with open('output1.html', 'w', encoding='utf-8') as file:
 			file.write(str(soup))
@@ -277,7 +277,7 @@ class Stock:
 
 	def news_sentiments(self): # Returns news articles curated via Finviz, Yahoo, and Google News, GET UNUSUAL OPTION ACTIVITY
 		BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		table = soup.find('table', {'class': 'fullview-news-outer'})
 		rows = table.find_all('tr')
@@ -296,13 +296,13 @@ class Stock:
 		# To get other pages, do googlenews.get_page(2), etc.
 
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}/news?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		links = soup.find_all('a', {'class': 'js-content-viewer wafer-caas Fw(b) Fz(18px) Lh(23px) LineClamp(2,46px) Fz(17px)--sm1024 Lh(19px)--sm1024 LineClamp(2,38px)--sm1024 mega-item-header-link Td(n) C(#0078ff):h C(#000) LineClamp(2,46px) LineClamp(2,38px)--sm1024 not-isInStreamVideoEnabled'})
 		news = [(link.get_text(), str('yahoo.com' + link['href'])) for link in links]
 
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}/press-releases?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		links = soup.find_all('a', {'class': 'js-content-viewer wafer-caas Fw(b) Fz(18px) Lh(23px) LineClamp(2,46px) Fz(17px)--sm1024 Lh(19px)--sm1024 LineClamp(2,38px)--sm1024 mega-item-header-link Td(n) C(#0078ff):h C(#000) LineClamp(2,46px) LineClamp(2,38px)--sm1024 not-isInStreamVideoEnabled'})
 		press_releases = [(link.get_text(), str('yahoo.com' + link['href'])) for link in links]
@@ -314,7 +314,7 @@ class Stock:
 	def financials(self): # OMEGALUL
 		# Displaying all information. Could leave this as a dictionary.
 		BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		table = soup.find('table', {'class': 'snapshot-table2'})
 		labels = table.find_all('td', {'class': 'snapshot-td2-cp'})
 		values = table.find_all('td', {'class': 'snapshot-td2'})
@@ -325,7 +325,7 @@ class Stock:
 
 		# yo
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}/key-statistics?p={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		# PE/G, market cap, profit margin, idk what else is important
 		div = soup.find('div', {'id': 'quote-summary'})
@@ -337,7 +337,7 @@ class Stock:
 		Returns a stocks short_selling information
 		'''
 		BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		labels = soup.find_all('td', {'class': 'snapshot-td2-cp'})
 		values = soup.find_all('td', {'class': 'snapshot-td2'})
@@ -350,7 +350,7 @@ class Stock:
 		Returns various information regarding the put call ratio of a stock.
 		'''
 		BASE_URL = f'https://www.alphaquery.com/stock/{self.ticker}/volatility-option-statistics/120-day/put-call-ratio-oi'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		ratio_volume = soup.find('tr', {'id': 'indicator-put-call-ratio-volume'})
 		ratio_open_interest = soup.find('tr', {'id': 'indicator-put-call-ratio-oi'})
@@ -363,7 +363,7 @@ class Stock:
 
 	def find_competition(self):
 		BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		td = soup.find_all('td', {'class': 'fullview-links'})[1]
 		sectors = td.find_all('a', {'class': 'tab-link'})
@@ -373,7 +373,7 @@ class Stock:
 
 	def etfs(self):
 		BASE_URL = f'https://etfdb.com/stock/{self.ticker}/'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		tbody = soup.find('tbody')
 		rows = tbody.find_all('tr')
 		rows = [[i.get_text() for i in row.find_all('td')] for row in rows]
@@ -382,7 +382,7 @@ class Stock:
 
 	def insider_trading(self):
 		BASE_URL = f'https://finviz.com/quote.ashx?t={self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		tr = soup.find_all('tr', {'class': "insider-sale-row-2"})
 		return [i.get_text() for i in tr]
@@ -403,7 +403,7 @@ class Stock:
 		df_data = []
 		# Earnings date: 
 		BASE_URL = f'https://finance.yahoo.com/quote/{self.ticker}?p={self.ticker}&.tsrc=fin-srch'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		
 		# Convert to datetime
 		earnings_date = soup.find('td', {'data-test': 'EARNINGS_DATE-value'})
@@ -411,7 +411,7 @@ class Stock:
 
 		# FDA approvals
 		BASE_URL = 'https://www.rttnews.com/corpinfo/fdacalendar.aspx'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		company = soup.find_all('div', {'data-th': 'Company Name'})
 
@@ -439,7 +439,7 @@ class Stock:
 
 	def big_money(self): # Returns recent institutional investments in a stock, as well as the largest shareholders and mutual funds holding the stock
 		BASE_URL = f'https://money.cnn.com/quote/shareholders/shareholders.html?symb={self.ticker}&subView=institutional'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 
 		# Top 10 Owners
 		df_data = []
@@ -463,7 +463,7 @@ class Stock:
 
 		# Recent instutional investments, from a better source this time
 		BASE_URL = f'https://fintel.io/so/us/{self.ticker}'
-		soup = _get_soup(BASE_URL)
+		soup = self._get_soup(BASE_URL)
 		table = soup.find('table', {'id': 'transactions'})
 		rows = table.find_all('tr')
 		df_data = []
